==> bibledit-web-1.7.zip: bibledit-web/help/scripts/about.php <==
<?php
/*
Copyright (©) 2003-2014 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<h1><?php echo Locale_Translate::_("About") ?></h1>
<p><?php echo Locale_Translate::_("Bibledit-Web") ?> <?php echo $this->version ?></p>
<p><a href="https://sites.google.com/site/bibleditweb">https://sites.google.com/site/bibleditweb</a></p>
<p>Copyright (©) 2003-2014 Teus Benschop.</p>
<p>This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.</p>
<p>This program is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose. See the GNU General Public License for more details.</p>
<p>You should have received a copy of the GNU General Public License along with this program. See also <a href="http://www.gnu.org/licenses/gpl.html" target="_blank">http://www.gnu.org/licenses/gpl.html</a>.</p>
<br>
<p><a href="freebible.php">The Free Bible</a></p>
<br>
<p><a href="changelog.php">ChangeLog</a></p>

==> bibledit-web-1.8.zip: bibledit-web/help/scripts/about.php <==
<?php
/*
Copyright (©) 2003-2014 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<h1><?php echo Locale_Translate::_("About") ?></h1>
<p><?php echo Locale_Translate::_("Bibledit-Web") ?> <?php echo Config_Logic::version () ?></p>
<p><a href="https://sites.google.com/site/bibleditweb">https://sites.google.com/site/bibleditweb</a></p>
<p>Copyright (©) 2003-2014 Teus Benschop.</p>
<p>This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.</p>
<p>This program is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose. See the GNU General Public License for more details.</p>
<p>You should have received a copy of the GNU General Public License along with this program. See also <a href="http://www.gnu.org/licenses/gpl.html" target="_blank">http://www.gnu.org/licenses/gpl.html</a>.</p>
<br>
<p><a href="freebible.php">The Free Bible</a></p>
<br>
<p><a href="changelog.php">ChangeLog</a></p>
